@@ -1,14 +1,13 @@
 \donttest{
-## Coerce data to a count matrix
-data("chevelon", package = "folio")
+data("cantabria")
 
 ## Assemblage diversity size comparison
 ## Warning: this may take a few seconds!
-h <- heterogeneity(chevelon, method = "shannon")
+h <- heterogeneity(cantabria, method = "shannon")
 h_sim <- simulate(h)
 plot(h_sim)
 
-r <- richness(chevelon, method = "count")
+r <- richness(cantabria, method = "count")
 r_sim <- simulate(r)
 plot(r_sim)
 }
